@@ -10,12 +10,13 @@ from bridger.metadata.views import MetadataMixin
 from bridger.viewsets.mixins import DocumentationMixin, ModelMixin
 from .metadata import PandasMetadata
 import numpy as np
+from .filters import PandasSearchFilter, PandasOrderingFilter, PandasDjangoFilterBackend
 
 class PandasAPIView(MetadataMixin, DocumentationMixin, ModelMixin, APIView):
 
     filter_backends = [
-        filters.OrderingFilter,
-        filters.SearchFilter,
+        PandasOrderingFilter,
+        PandasSearchFilter,
         DjangoFilterBackend,
     ]
 
@@ -27,11 +28,15 @@ class PandasAPIView(MetadataMixin, DocumentationMixin, ModelMixin, APIView):
 
     def filter_queryset(self, queryset: QuerySet) -> QuerySet:
         for backend in list(self.filter_backends):
-            if backend in [DjangoFilterBackend, filters.SearchFilter]:
-                if queryset.exists():
-                    queryset = backend().filter_queryset(self.request, queryset, self)
+            print(backend)
+            queryset = backend().filter_queryset(self.request, queryset, self)
         return queryset
 
+    def filter_dataframe(self, df):
+        for backend in list(self.filter_backends):
+            if hasattr(backend, "filter_dataframe"):
+                df = backend().filter_dataframe(self.request, df, self)
+        return df
 
     def get_queryset(self):
         assert hasattr(self, "queryset"), "Either specify a queryset or implement the get_queryset method."
@@ -56,21 +61,6 @@ class PandasAPIView(MetadataMixin, DocumentationMixin, ModelMixin, APIView):
         df = self.manipulate_dataframe(self.get_dataframe(request, **kwargs))
         df = df.replace([np.inf, -np.inf], np.nan)
         df = df.where(pd.notnull(df), None)
-        if filters.OrderingFilter in list(self.filter_backends) and self.get_queryset().exists() and not df.empty:
-            orderings = filters.OrderingFilter().get_ordering(request, self.get_queryset(), self)
-            df = self.sort_df(df, orderings)
+        df = self.filter_dataframe(df)
         aggregates = self.get_aggregates(request, df) if not df.empty else {}
-        return Response({"results": df.to_dict("records"), "aggregates": aggregates})
-
-    @classmethod
-    def sort_df(cls, df, ordering: list):
-        #receive a list of django ordering 
-        ascending = True
-        parsed_ordering = []
-        if ordering:
-            for o in ordering:
-                parsed_ordering.append(o.replace('-', ''))
-                if o[0] == '-':
-                    ascending = False
-            return df.sort_values(by=parsed_ordering, ascending=ascending)
-        return df
\ No newline at end of file
+        return Response({"results": df.to_dict("records"), "aggregates": aggregates})
\ No newline at end of file
